==> 2.8.1.tar.gz: test/checkout_session_test.dart <==
import 'package:test/test.dart';
import 'package:forestvpn_api/forestvpn_api.dart';

// tests for CheckoutSession
void main() {
  final instance = CheckoutSessionBuilder();
  // TODO add properties to the builder and call build()

  group(CheckoutSession, () {
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // String cancelUrl
    test('to test the property `cancelUrl`', () async {
      // TODO
    });

    // String successUrl
    test('to test the property `successUrl`', () async {
      // TODO
    });

    // String redirectUrl
    test('to test the property `redirectUrl`', () async {
      // TODO
    });

    // String currency
    test('to test the property `currency`', () async {
      // TODO
    });

    // int amountSubtotal
    test('to test the property `amountSubtotal`', () async {
      // TODO
    });

    // int amountTotal
    test('to test the property `amountTotal`', () async {
      // TODO
    });

    // String locale
    test('to test the property `locale`', () async {
      // TODO
    });

    // String email
    test('to test the property `email`', () async {
      // TODO
    });

    // BuiltList<CheckoutSessionProducts> products
    test('to test the property `products`', () async {
      // TODO
    });

    // String paymentStatus
    test('to test the property `paymentStatus`', () async {
      // TODO
    });

    // String status
    test('to test the property `status`', () async {
      // TODO
    });

    // Trial period duration in ISO 8601 format.
    // String trialPeriod
    test('to test the property `trialPeriod`', () async {
      // TODO
    });

    // String user
    test('to test the property `user`', () async {
      // TODO
    });

    // DateTime createdAt
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // DateTime expiresAt
    test('to test the property `expiresAt`', () async {
      // TODO
    });

  });
}

==> 2.9.0.tar.gz: test/checkout_session_test.dart <==
import 'package:test/test.dart';
import 'package:forestvpn_api/forestvpn_api.dart';

// tests for CheckoutSession
void main() {
  final instance = CheckoutSessionBuilder();
  // TODO add properties to the builder and call build()

  group(CheckoutSession, () {
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // String cancelUrl
    test('to test the property `cancelUrl`', () async {
      // TODO
    });

    // String successUrl
    test('to test the property `successUrl`', () async {
      // TODO
    });

    // String redirectUrl
    test('to test the property `redirectUrl`', () async {
      // TODO
    });

    // String currency
    test('to test the property `currency`', () async {
      // TODO
    });

    // int amountSubtotal
    test('to test the property `amountSubtotal`', () async {
      // TODO
    });

    // num amountSubtotalDecimal
    test('to test the property `amountSubtotalDecimal`', () async {
      // TODO
    });

    // int amountTotal
    test('to test the property `amountTotal`', () async {
      // TODO
    });

    // num amountTotalDecimal
    test('to test the property `amountTotalDecimal`', () async {
      // TODO
    });

    // String locale
    test('to test the property `locale`', () async {
      // TODO
    });

    // String email
    test('to test the property `email`', () async {
      // TODO
    });

    // BuiltList<CheckoutSessionProduct> products
    test('to test the property `products`', () async {
      // TODO
    });

    // String paymentStatus
    test('to test the property `paymentStatus`', () async {
      // TODO
    });

    // String status
    test('to test the property `status`', () async {
      // TODO
    });

    // Trial period duration in ISO 8601 format.
    // String trialPeriod
    test('to test the property `trialPeriod`', () async {
      // TODO
    });

    // String user
    test('to test the property `user`', () async {
      // TODO
    });

    // DateTime createdAt
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // DateTime expiresAt
    test('to test the property `expiresAt`', () async {
      // TODO
    });

  });
}
